@@ -1236,6 +1236,15 @@ static void update_new_device(struct device *dev, int8_t rssi,
 		size += fill_hal_prop(buf + size, HAL_PROP_DEVICE_NAME,
 						strlen(dev->name), dev->name);
 		ev->num_props++;
+
+		/* when updating name also send stored friendly name */
+		if (dev->friendly_name) {
+			size += fill_hal_prop(buf + size,
+						HAL_PROP_DEVICE_FRIENDLY_NAME,
+						strlen(dev->friendly_name),
+						dev->friendly_name);
+			ev->num_props++;
+		}
 	}
 
 	ipc_send_notif(hal_ipc, HAL_SERVICE_ID_BLUETOOTH, HAL_EV_DEVICE_FOUND,
@@ -1298,6 +1307,15 @@ static void update_device(struct device *dev, int8_t rssi,
 		size += fill_hal_prop(buf + size, HAL_PROP_DEVICE_NAME,
 						strlen(dev->name), dev->name);
 		ev->num_props++;
+
+		/* when updating name also send stored friendly name */
+		if (dev->friendly_name) {
+			size += fill_hal_prop(buf + size,
+						HAL_PROP_DEVICE_FRIENDLY_NAME,
+						strlen(dev->friendly_name),
+						dev->friendly_name);
+			ev->num_props++;
+		}
 	}
 
 	if (ev->num_props)
@@ -1305,6 +1323,21 @@ static void update_device(struct device *dev, int8_t rssi,
 					HAL_EV_REMOTE_DEVICE_PROPS, size, buf);
 }
 
+static bool is_new_device(const struct device *dev, unsigned int flags)
+{
+	if (dev->found)
+		return false;
+
+	if (dev->bond_state == HAL_BOND_STATE_BONDED)
+		return false;
+
+	if (dev->bdaddr_type != BDADDR_BREDR &&
+				!(flags & (EIR_LIM_DISC | EIR_GEN_DISC)))
+		return false;
+
+	return true;
+}
+
 static void update_found_device(const bdaddr_t *bdaddr, uint8_t bdaddr_type,
 					int8_t rssi, bool confirm,
 					const uint8_t *data, uint8_t data_len)
@@ -1316,35 +1349,28 @@ static void update_found_device(const bdaddr_t *bdaddr, uint8_t bdaddr_type,
 
 	eir_parse(&eir, data, data_len);
 
-	dev = find_device(bdaddr);
-
-	if (bdaddr_type != BDADDR_BREDR) {
-		/* Notify Gatt if its registered for LE events */
-		if (gatt_device_found_cb)
-			gatt_device_found_cb(bdaddr, bdaddr_type, rssi,
-							sizeof(eir), &eir);
-
-		if (!dev && adapter.cur_discovery_type != SCAN_TYPE_NONE &&
-				!(eir.flags & (EIR_LIM_DISC | EIR_GEN_DISC))) {
-			eir_data_free(&eir);
-			return;
-		}
-	}
+	dev = get_device(bdaddr, bdaddr_type);
 
 	/* Device found event needs to be send also for known device if this is
 	 * new discovery session. Otherwise framework will ignore it.
 	 */
-	if (!dev || !dev->found) {
-		if (!dev)
-			dev = create_device(bdaddr, bdaddr_type);
-
+	if (is_new_device(dev, eir.flags))
 		update_new_device(dev, rssi, &eir);
-	} else {
+	else
 		update_device(dev, rssi, &eir, bdaddr_type);
-	}
 
 	eir_data_free(&eir);
 
+	/* Notify Gatt if its registered for LE events */
+	if (bdaddr_type != BDADDR_BREDR && gatt_device_found_cb) {
+		bool discoverable;
+
+		discoverable = eir.flags & (EIR_LIM_DISC | EIR_GEN_DISC);
+
+		gatt_device_found_cb(bdaddr, bdaddr_type, rssi, data_len, data,
+								discoverable);
+	}
+
 	if (dev->bond_state != HAL_BOND_STATE_BONDED)
 		cache_device(dev);
 
@@ -2759,6 +2785,7 @@ static void handle_get_adapter_prop_cmd(const void *buf, uint16_t len)
 
 static void get_adapter_properties(void)
 {
+	/* TODO should be done in single notification */
 	get_adapter_address();
 	get_adapter_name();
 	get_adapter_uuids();
@@ -3292,12 +3319,13 @@ static uint8_t get_device_timestamp(struct device *dev)
 
 static void get_remote_device_props(struct device *dev)
 {
+	/* TODO should be done in single notification */
+	get_device_friendly_name(dev);
 	get_device_name(dev);
 	get_device_uuids(dev);
 	get_device_class(dev);
 	get_device_type(dev);
 	get_device_service_rec(dev);
-	get_device_friendly_name(dev);
 	get_device_rssi(dev);
 	get_device_version_info(dev);
 	get_device_timestamp(dev);
@@ -3464,9 +3492,6 @@ static uint8_t set_device_friendly_name(struct device *dev, const uint8_t *val,
 	else
 		store_device_info(dev, CACHE_FILE);
 
-	send_device_property(&dev->bdaddr, HAL_PROP_DEVICE_FRIENDLY_NAME,
-				strlen(dev->friendly_name), dev->friendly_name);
-
 	return HAL_STATUS_SUCCESS;
 }
 
