@@ -36,6 +36,7 @@
 #include "src/profile.h"
 #include "src/service.h"
 #include "src/dbus-common.h"
+#include "src/shared/util.h"
 #include "src/error.h"
 #include "attrib/gattrib.h"
 #include "attrib/att.h"
@@ -380,7 +381,7 @@ static void read_feature_cb(guint8 status, const guint8 *pdu, guint16 len,
 		return;
 	}
 
-	csc->feature = att_get_u16(value);
+	csc->feature = get_le16(value);
 
 	if ((csc->feature & MULTI_SENSOR_LOC_SUPPORT)
 						&& (csc->locations == NULL))
@@ -446,8 +447,8 @@ static void discover_desc_cb(guint8 status, const guint8 *pdu,
 		char *msg;
 
 		value = list->data[i];
-		handle = att_get_u16(value);
-		uuid = att_get_u16(value + 2);
+		handle = get_le16(value);
+		uuid = get_le16(value + 2);
 
 		if (uuid != GATT_CLIENT_CHARAC_CFG_UUID)
 			continue;
@@ -456,16 +457,16 @@ static void discover_desc_cb(guint8 status, const guint8 *pdu,
 			ch->csc->measurement_ccc_handle = handle;
 
 			if (g_slist_length(ch->csc->cadapter->watchers) == 0) {
-				att_put_u16(0x0000, attr_val);
+				put_le16(0x0000, attr_val);
 				msg = g_strdup("Disable measurement");
 			} else {
-				att_put_u16(GATT_CLIENT_CHARAC_CFG_NOTIF_BIT,
+				put_le16(GATT_CLIENT_CHARAC_CFG_NOTIF_BIT,
 								attr_val);
 				msg = g_strdup("Enable measurement");
 			}
 
 		} else if (g_strcmp0(ch->uuid, SC_CONTROL_POINT_UUID) == 0) {
-			att_put_u16(GATT_CLIENT_CHARAC_CFG_IND_BIT, attr_val);
+			put_le16(GATT_CLIENT_CHARAC_CFG_IND_BIT, attr_val);
 			msg = g_strdup("Enable SC Control Point indications");
 		} else {
 			break;
@@ -573,8 +574,8 @@ static void process_measurement(struct csc *csc, const uint8_t *pdu,
 		}
 
 		m.has_wheel_rev = true;
-		m.wheel_rev = att_get_u32(pdu);
-		m.last_wheel_time = att_get_u16(pdu + 4);
+		m.wheel_rev = get_le32(pdu);
+		m.last_wheel_time = get_le16(pdu + 4);
 		pdu += 6;
 		len -= 6;
 	}
@@ -586,8 +587,8 @@ static void process_measurement(struct csc *csc, const uint8_t *pdu,
 		}
 
 		m.has_crank_rev = true;
-		m.crank_rev = att_get_u16(pdu);
-		m.last_crank_time = att_get_u16(pdu + 2);
+		m.crank_rev = get_le16(pdu);
+		m.last_crank_time = get_le16(pdu + 2);
 		pdu += 4;
 		len -= 4;
 	}
@@ -816,7 +817,7 @@ static void enable_measurement(gpointer data, gpointer user_data)
 	if (csc->attrib == NULL || !handle)
 		return;
 
-	att_put_u16(GATT_CLIENT_CHARAC_CFG_NOTIF_BIT, value);
+	put_le16(GATT_CLIENT_CHARAC_CFG_NOTIF_BIT, value);
 	msg = g_strdup("Enable measurement");
 
 	gatt_write_char(csc->attrib, handle, value, sizeof(value),
@@ -833,7 +834,7 @@ static void disable_measurement(gpointer data, gpointer user_data)
 	if (csc->attrib == NULL || !handle)
 		return;
 
-	att_put_u16(0x0000, value);
+	put_le16(0x0000, value);
 	msg = g_strdup("Disable measurement");
 
 	gatt_write_char(csc->attrib, handle, value, sizeof(value),
@@ -1166,7 +1167,7 @@ static DBusMessage *set_cumulative_wheel_rev(DBusConnection *conn,
 	csc->pending_req = req;
 
 	att_val[0] = SET_CUMULATIVE_VALUE;
-	att_put_u32(value, att_val + 1);
+	put_le32(value, att_val + 1);
 
 	gatt_write_char(csc->attrib, csc->controlpoint_val_handle, att_val,
 		sizeof(att_val), controlpoint_write_cb, req);
